# Перенос приема

Позволяет изменить время созданного приема.

**POST**: `https://api3.medelement.com/v2/doctor/reception/change_reception_date`

## Параметры:

| Название       | Тип    | Описание                                |
| -------------- | ------ | --------------------------------------- |
| reception_code | Bigint | Уникальный код приема                   |
| doctor_code    | Bigint | Уникальный код врача                    |
| start_time     | String | Дата начала приема (01.05.2024 8:00)    |
| end_time       | String | Дата окончания приема (01.05.2024 8:30) |

## Ответ:

HTTP/1.1 200 OK

```json
[]
```
